-- game.lua
-- the game class can have several states
-- using different draw, update functions

require 'Player.lua'
require 'Enemy.lua'

Game = Class(function(self)
	
	self.c = Camera(vector(0,0), 1, 0)
	self.p = Player(self)
	self.playerDead = false
	
	love.graphics.setBackgroundColor(255,255,255)
	-- scatter some eyes
	self.eyes = {}
	for i=1,1 do
		table.insert(self.eyes, Eye(nil,vector(math.random()*800-400,math.random()*600-300), self, math.random()*4+4))
	end
	
	self.enemyStr = 1
	self.enemyTimeout = 2
	self.e = Enemy(self, vector(200,200), self.enemyStr)
end)

function Game:update(dt)
	dt = math.min(dt, 0.1) -- min 10 fps
	if self.e.dead == true then
		self.enemyTimeout = self.enemyTimeout - dt
		if self.enemyTimeout < 0 then
			self.enemyTimout = 2
			local newX = -(self.p.p.x/math.abs(self.p.p.x))*200
			local newY = -(self.p.p.y/math.abs(self.p.p.y))*100
			self.enemyStr = self.enemyStr + 1
			self.e = Enemy(self, vector(newX, newY), self.enemyStr, (math.random()-0.5)*20+20*math.sqrt(self.enemyStr)+100, (math.random()-0.5)*20+20*self.enemyStr+150)
		end
	end
	if self.playerDead then 
		self.e:idle(dt)
		return
	end
	
	self.p:update(dt)
	for i,eye in ipairs(self.eyes) do
		if eye.p:dist(self.p.p) < (self.p.size+eye.size) then
			eye.p = vector(0,0) --set the eye position to zero and then
			self.p:addEye(self, eye.size) -- insert the eye to teh player
			table.remove(self.eyes, i) -- remove from the list of eyes
			love.audio.play(Eye.blinkSound)
		end
	end
	if #self.eyes == 0 then
		for i=1,1 do
			--table.insert(self.eyes, Eye(nil,vector(math.random()*800-400,math.random()*600-300), self, math.random()*4+4))
		end
	end
	
	self.e:update(dt)
	
end

function Game:draw()
	self.c:predraw()
	
	love.graphics.setColor(0,0,0,255)
	
	
	self.e:draw()
	
	for i,eye in ipairs(self.eyes) do
		eye:draw(nil, true)
	end
	
	if self.playerDead then
		love.graphics.print("You are dead.",0,0)
	else
		self.p:draw()
	end
	
	self.c:postdraw()
end

function Game:keyPressed(k)
	self.p:keyPressed(k)
end